#include "text.h"

/* Change font here */
const char* fontname = "SourceSansPro-Regular.ttf"; //!< The font used to render text

/**
 * @brief Displays a string of text on the screen using a font, centered
 * @param sdlRenderer the renderer to use
 * @param x x coordinate for middle of the rendered text
 * @param y y coordinate for middle of the rendered text
 * @param fontsize the size of the text
 * @param text the text to render
 * @param r red component
 * @param g green component
 * @param b blue component
 */
void centeredtextRGB(SDL_Renderer* sdlRenderer, int x, int y, int fontsize, std::string text, Uint8 r, Uint8 g, Uint8 b) {
    TTF_Init();
    
    TTF_Font *font = TTF_OpenFont(fontname, fontsize);
    if(font == nullptr) {
        throw std::runtime_error("Font not found!");
    }
    SDL_Color colour = {r, g, b};
    SDL_Surface *text_surface = TTF_RenderUTF8_Blended(font, text.c_str(), colour);
    SDL_Texture *text_texture = SDL_CreateTextureFromSurface(sdlRenderer, text_surface);
    SDL_Rect rect = {x-text_surface->w/2, y-text_surface->h/2, text_surface->w, text_surface->h};
    SDL_RenderCopy(sdlRenderer, text_texture, NULL, &rect);
    
    TTF_CloseFont(font);
    SDL_FreeSurface(text_surface);
    SDL_DestroyTexture(text_texture);
}

/**
 * @brief Displays a string of text on the screen using a font, centered
 * @param sdlRenderer the renderer to use
 * @param x x coordinate for middle of the rendered text
 * @param y y coordinate for middle of the rendered text
 * @param fontsize the size of the text
 * @param text the text to render
 * @param colour colour in 0xRRGGBBAA format, but AA is ignored
 */
void centeredtextColor(SDL_Renderer* sdlRenderer, int x, int y, int fontsize, std::string text, Uint32 colour) {
    centeredtextRGB(sdlRenderer, x, y, fontsize, text, Uint8(colour>>24), Uint8(colour>>16), Uint8(colour>>8));
}

/**
 * @brief Displays a string of text on the screen using a font, left aligned
 * @param sdlRenderer the renderer to use
 * @param x x coordinate for the beginning of the rendered text
 * @param y y coordinate for middle of the rendered text
 * @param fontsize the size of the text
 * @param text the text to render
 * @param r red component
 * @param g green component
 * @param b blue component
 */
void textRGB(SDL_Renderer* sdlRenderer, int x, int y, int fontsize, std::string text, Uint8 r, Uint8 g, Uint8 b) {
    TTF_Init();
    
    TTF_Font *font = TTF_OpenFont(fontname, fontsize);
    if(font == nullptr) {
        throw std::runtime_error("Font not found!");
    }
    SDL_Color colour = {r, g, b};
    SDL_Surface *text_surface = TTF_RenderUTF8_Blended(font, text.c_str(), colour);
    SDL_Texture *text_texture = SDL_CreateTextureFromSurface(sdlRenderer, text_surface);
    SDL_Rect rect = {x, y-text_surface->h/2, text_surface->w, text_surface->h};
    SDL_RenderCopy(sdlRenderer, text_texture, NULL, &rect);
    
    TTF_CloseFont(font);
    SDL_FreeSurface(text_surface);
    SDL_DestroyTexture(text_texture);
}

/**
 * @brief Displays a string of text on the screen using a font, left aligned
 * @param sdlRenderer the renderer to use
 * @param x x coordinate for the beginning of the rendered text
 * @param y y coordinate for middle of the rendered text
 * @param fontsize the size of the text
 * @param text the text to render
 * @param colour colour in 0xRRGGBBAA format, but AA is ignored
 */
void textColor(SDL_Renderer* sdlRenderer, int x, int y, int fontsize, std::string text, Uint32 colour) {
    textRGB(sdlRenderer, x, y, fontsize, text, Uint8(colour>>24), Uint8(colour>>16), Uint8(colour>>8));
}
